@@ -14,6 +14,8 @@ use slab::Slab;
 #[cfg(all(not(feature = "async-std-runtime"), feature = "tokio-runtime"))]
 use tokio::sync::RwLock;
 
+use super::inode_generator::InodeGenerator;
+use super::path_filesystem::PathFilesystem;
 use crate::helper::Apply;
 use crate::notify::Notify;
 use crate::raw::reply::*;
@@ -21,9 +23,6 @@ use crate::raw::{Filesystem, Request};
 use crate::{Errno, SetAttr};
 use crate::{Inode, Result};
 
-use super::inode_generator::InodeGenerator;
-use super::path_filesystem::PathFilesystem;
-
 const ROOT_INODE: Inode = 1;
 
 #[derive(Debug, Eq, PartialEq, Hash, Clone)]
@@ -595,13 +594,13 @@ where
             .await
     }
 
-    async fn statsfs(&self, req: Request, inode: u64) -> Result<ReplyStatFs> {
+    async fn statfs(&self, req: Request, inode: u64) -> Result<ReplyStatFs> {
         let inode_name_manager = self.inode_name_manager.read().await;
         let path = inode_name_manager
             .get_absolute_path(inode)
             .ok_or_else(Errno::new_not_exist)?;
 
-        self.path_filesystem.statsfs(req, path.as_ref()).await
+        self.path_filesystem.statfs(req, path.as_ref()).await
     }
 
     async fn release(
@@ -648,7 +647,7 @@ where
         req: Request,
         inode: u64,
         name: &OsStr,
-        value: &OsStr,
+        value: &[u8],
         flags: u32,
         position: u32,
     ) -> Result<()> {
@@ -773,6 +772,7 @@ where
                 inode,
                 kind: entry.kind,
                 name: entry.name,
+                offset: entry.offset,
             }));
         }
 
@@ -1083,6 +1083,7 @@ where
                 generation: 0,
                 kind: entry.kind,
                 name: entry.name,
+                offset: entry.offset,
                 attr: (inode, entry.attr).into(),
                 entry_ttl: entry.entry_ttl,
                 attr_ttl: entry.attr_ttl,
