@@ -4,9 +4,6 @@ use async_trait::async_trait;
 use bytes::Bytes;
 use futures_util::stream::Stream;
 
-use crate::notify::Notify;
-use crate::{Result, SetAttr};
-
 #[cfg(feature = "file-lock")]
 use super::reply::ReplyLock;
 use super::reply::{
@@ -15,6 +12,8 @@ use super::reply::{
     ReplyStatFs, ReplyWrite, ReplyXAttr,
 };
 use super::Request;
+use crate::notify::Notify;
+use crate::{Result, SetAttr};
 
 #[allow(unused_variables)]
 #[async_trait]
@@ -161,7 +160,9 @@ pub trait PathFilesystem {
     /// fh, and use this in other all other file operations (read, write, flush, release, fsync).
     /// Filesystem may also implement stateless file I/O and not store anything in fh. There are
     /// also some flags (`direct_io`, `keep_cache`) which the filesystem may set, to change the way
-    /// the file is opened.
+    /// the file is opened.  A file system need not implement this method if it
+    /// sets [`MountOptions::no_open_support`][crate::MountOptions::no_open_support] and if the
+    /// kernel supports `FUSE_NO_OPEN_SUPPORT`.
     ///
     /// # Notes:
     ///
@@ -207,7 +208,7 @@ pub trait PathFilesystem {
     }
 
     /// get filesystem statistics.
-    async fn statsfs(&self, req: Request, path: &OsStr) -> Result<ReplyStatFs> {
+    async fn statfs(&self, req: Request, path: &OsStr) -> Result<ReplyStatFs> {
         Err(libc::ENOSYS.into())
     }
 
@@ -248,7 +249,7 @@ pub trait PathFilesystem {
         req: Request,
         path: &OsStr,
         name: &OsStr,
-        value: &OsStr,
+        value: &[u8],
         flags: u32,
         position: u32,
     ) -> Result<()> {
@@ -306,11 +307,11 @@ pub trait PathFilesystem {
     /// `fh`, and use this in other all other directory stream operations
     /// ([`readdir`][PathFilesystem::readdir], [`releasedir`][PathFilesystem::releasedir],
     /// [`fsyncdir`][PathFilesystem::fsyncdir]). Filesystem may also implement stateless directory
-    /// I/O and not store anything in `fh`, though that makes it impossible to implement standard
-    /// conforming directory stream operations in case the contents of the directory can change
-    /// between `opendir` and [`releasedir`][PathFilesystem::releasedir].
+    /// I/O and not store anything in `fh`.  A file system need not implement this method if it
+    /// sets [`MountOptions::no_open_dir_support`][crate::MountOptions::no_open_dir_support] and if
+    /// the kernel supports `FUSE_NO_OPENDIR_SUPPORT`.
     async fn opendir(&self, req: Request, path: &OsStr, flags: u32) -> Result<ReplyOpen> {
-        Ok(ReplyOpen { fh: 0, flags: 0 })
+        Err(libc::ENOSYS.into())
     }
 
     /// read directory. `offset` is used to track the offset of the directory entries. `fh` will
