@@ -151,7 +151,9 @@ pub trait Filesystem {
     /// fh, and use this in other all other file operations (read, write, flush, release, fsync).
     /// Filesystem may also implement stateless file I/O and not store anything in fh. There are
     /// also some flags (`direct_io`, `keep_cache`) which the filesystem may set, to change the way
-    /// the file is opened.
+    /// the file is opened. A filesystem need not implement this method if it
+    /// sets [`MountOptions::no_open_support`][crate::MountOptions::no_open_support] and if the
+    /// kernel supports `FUSE_NO_OPEN_SUPPORT`.
     ///
     /// # Notes:
     ///
@@ -196,7 +198,7 @@ pub trait Filesystem {
     }
 
     /// get filesystem statistics.
-    async fn statsfs(&self, req: Request, inode: Inode) -> Result<ReplyStatFs> {
+    async fn statfs(&self, req: Request, inode: Inode) -> Result<ReplyStatFs> {
         Err(libc::ENOSYS.into())
     }
 
@@ -231,15 +233,16 @@ pub trait Filesystem {
         req: Request,
         inode: Inode,
         name: &OsStr,
-        value: &OsStr,
+        value: &[u8],
         flags: u32,
         position: u32,
     ) -> Result<()> {
         Err(libc::ENOSYS.into())
     }
 
-    /// get an extended attribute. If size is too small, use [`ReplyXAttr::Size`] to return correct
-    /// size. If size is enough, use [`ReplyXAttr::Data`] to send it, or return error.
+    /// Get an extended attribute. If `size` is too small, return `Err<ERANGE>`.
+    /// Otherwise, use [`ReplyXAttr::Data`] to send the attribute data, or
+    /// return an error.
     async fn getxattr(
         &self,
         req: Request,
@@ -250,8 +253,10 @@ pub trait Filesystem {
         Err(libc::ENOSYS.into())
     }
 
-    /// list extended attribute names. If size is too small, use [`ReplyXAttr::Size`] to return
-    /// correct size. If size is enough, use [`ReplyXAttr::Data`] to send it, or return error.
+    /// List extended attribute names.
+    ///
+    /// If `size` is too small, return `Err<ERANGE>`.  Otherwise, use
+    /// [`ReplyXAttr::Data`] to send the attribute list, or return an error.
     async fn listxattr(&self, req: Request, inode: Inode, size: u32) -> Result<ReplyXAttr> {
         Err(libc::ENOSYS.into())
     }
@@ -281,11 +286,11 @@ pub trait Filesystem {
     /// `fh`, and use this in other all other directory stream operations
     /// ([`readdir`][Filesystem::readdir], [`releasedir`][Filesystem::releasedir],
     /// [`fsyncdir`][Filesystem::fsyncdir]). Filesystem may also implement stateless directory
-    /// I/O and not store anything in `fh`, though that makes it impossible to implement standard
-    /// conforming directory stream operations in case the contents of the directory can change
-    /// between `opendir` and [`releasedir`][Filesystem::releasedir].
+    /// I/O and not store anything in `fh`.  A file system need not implement this method if it
+    /// sets [`MountOptions::no_open_dir_support`][crate::MountOptions::no_open_dir_support] and
+    /// if the kernel supports `FUSE_NO_OPENDIR_SUPPORT`.
     async fn opendir(&self, req: Request, inode: Inode, flags: u32) -> Result<ReplyOpen> {
-        Ok(ReplyOpen { fh: 0, flags: 0 })
+        Err(libc::ENOSYS.into())
     }
 
     /// read directory. `offset` is used to track the offset of the directory entries. `fh` will
